==> openurp-edu-api4j-0.31.4-sources.jar: org/openurp/edu/clazz/service/limit/impl/DefaultRestrictionMetaProvider.java <==
/*
 * OpenURP, Agile University Resource Planning Solution.
 *
 * Copyright © 2014, The OpenURP Software.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful.
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.openurp.edu.clazz.service.limit.impl;

import java.util.ArrayList;
import java.util.List;

import org.beangle.commons.lang.tuple.Pair;
import org.openurp.edu.clazz.model.RestrictionMeta;
import org.openurp.edu.clazz.service.limit.RestrictionMetaFilter;
import org.openurp.edu.clazz.service.limit.RestrictionMetaProvider;

public class DefaultRestrictionMetaProvider implements RestrictionMetaProvider {
  private List<RestrictionMetaFilter> filters = new ArrayList<RestrictionMetaFilter>();

  private static final RestrictionMeta[] enums = RestrictionMeta.values();

  public List<RestrictionMeta> getRestrictionMetas() {
    List<RestrictionMeta> results = new ArrayList<RestrictionMeta>();
    for (RestrictionMeta courseLimitMetaEnum : enums) {
      boolean append = true;
      for (RestrictionMetaFilter filter : filters) {
        if (!filter.accept(courseLimitMetaEnum)) {
          append = false;
          break;
        }
      }
      if (append) {
        results.add(courseLimitMetaEnum);
      }
    }
    return results;
  }

  public void setFilters(List<RestrictionMetaFilter> filters) {
    this.filters = filters;
  }
}

==> openurp-edu-api4j-0.39.0-sources.jar: org/openurp/edu/clazz/service/limit/impl/DefaultRestrictionMetaProvider.java <==
/*
 * OpenURP, Agile University Resource Planning Solution.
 *
 * Copyright © 2014, The OpenURP Software.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful.
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.openurp.edu.clazz.service.limit.impl;

import java.util.ArrayList;
import java.util.List;

import org.openurp.edu.clazz.model.ClazzRestrictionMeta;
import org.openurp.edu.clazz.service.limit.RestrictionMetaFilter;
import org.openurp.edu.clazz.service.limit.RestrictionMetaProvider;

public class DefaultRestrictionMetaProvider implements RestrictionMetaProvider {
  private List<RestrictionMetaFilter> filters = new ArrayList<RestrictionMetaFilter>();

  private static final ClazzRestrictionMeta[] enums = ClazzRestrictionMeta.values();

  public List<ClazzRestrictionMeta> getRestrictionMetas() {
    List<ClazzRestrictionMeta> results = new ArrayList<ClazzRestrictionMeta>();
    for (ClazzRestrictionMeta courseLimitMetaEnum : enums) {
      boolean append = true;
      for (RestrictionMetaFilter filter : filters) {
        if (!filter.accept(courseLimitMetaEnum)) {
          append = false;
          break;
        }
      }
      if (append) {
        results.add(courseLimitMetaEnum);
      }
    }
    return results;
  }

  public void setFilters(List<RestrictionMetaFilter> filters) {
    this.filters = filters;
  }
}
